Function for computing log-likelihood conditional on the estimated random effects from the data and specified parameter estimates of a PHMM.
phmm.cond.loglik(time, delta, z, beta, w, b)Follow-up time (right censored data).
The status indicator (0=alive, 1=dead; or TRUE=dead,
FALSE=alive).
Numeric matrix (Nxnfixed) of covariates for fixed
effects.
Fitted fixed effects coefficients (p-vector).
Numeric matrix (Nxnrandom) of covariates for random
effects.
Numeric matrix (Nxnrandom) of random effects
estimates.
The PHMM log-likelihood conditional on the estimated random effects.